export default class BitBuffer {
    /**
     * BitBuffer class is the core class for computational process, shifting.
     *
     * @param MaxHalfSize - Half the size that `BitBuffer` can store
     * @param _buffer - Private property that the main data will be stored in.
     * @param _left - Left part of `_buffer`, type of this property is `BitBuffer` and the size is half of the `_buffer`.
     * @param _right - Right part of `_buffer`, type of this property is `BitBuffer` and the size is half of the
     *   `_buffer`.
     */
    private static readonly MaxHalfSize;
    private _left;
    private _right;
    private _buffer;
    get buffer(): number[];
    /**
     * Setter for _buffer.
     *
     * @param value - The new buffer value.
     */
    set buffer(value: number[]);
    length: number;
    /**
     * Getter for _left.
     *
     * @returns The left half of the buffer.
     */
    get left(): BitBuffer | undefined;
    /**
     * Setter for _left.
     *
     * @param value - The new left half of the buffer.
     */
    set left(value: BitBuffer | undefined);
    /**
     * Getter for _right.
     *
     * @returns The right half of the buffer.
     */
    get right(): BitBuffer | undefined;
    /**
     * Setter for _right.
     *
     * @param value - The new right half of the buffer.
     */
    set right(value: BitBuffer | undefined);
    /**
     * Creates a new BitBuffer, you can give an array of bits, or you can initialize it by length.
     *
     * @param lengthOrBuffer - The length of the buffer or an array representing the buffer.
     * @throws Will throw an error if the length is greater than 10.
     */
    constructor(lengthOrBuffer: number[] | number);
    /**
     * Creates new BitBuffer from it halves.
     *
     * @param left - New Buffer Left side
     * @param right - New Buffer Right side
     * @throws Will throw an error if the left and right halves are not of equal length.
     */
    constructor(left: number[], right: number[]);
    /**
     * Checks if the length is valid.
     *
     * @param length - The length to check.
     * @throws Will throw an error if the length is greater than 10.
     */
    private static checkLength;
    /**
     * Shifts a buffer to the left by a specified number of positions.
     *
     * @param child - The buffer to shift.
     * @param position - The number of positions to shift by.
     * @returns A new shifted BitBuffer.
     * @throws Will throw an error if the shift is greater than the buffer length.
     */
    shiftLeft(child: BitBuffer, position: number): BitBuffer;
    /**
     * Shifts the left half of the buffer to the left by a specified number of positions.
     *
     * @param position - The number of positions to shift by.
     * @throws Will throw an error if the left half of the buffer is undefined.
     */
    leftShiftLeft(position: number): void;
    /**
     * Shifts the right half of the buffer to the left by a specified number of positions.
     *
     * @param position - The number of positions to shift by.
     * @throws Will throw an error if the right half of the buffer is undefined.
     */
    leftShiftRight(position: number): void;
    /**
     * Swap left and right parts of the buffer.
     *
     * @returns {BitBuffer} - The BitBuffer instance with its left and right parts swapped.
     */
    swap(): BitBuffer;
    xor(second: BitBuffer): BitBuffer;
    toString(): string;
}
