import { Keys } from '../entity/keys';
import BitBufferArray from './BitBufferArray';
import '../extensions/string.extension';
export default class Cryptography {
    /**
     * Generates a key using the provided secret array.
     *
     * @param {number[]} secret - The secret bit array used to generate the key. Must have a length of 10.
     * @returns {Keys} - An object containing the generated keys.
     * @throws {Error} - Throws an error if the secret array does not have a length of 10.
     */
    static GenerateKey(secret: number[]): Keys;
    /**
     * Encrypts the provided string using the provided keys.
     *
     * @param {string} string - The string to encrypt.
     * @param {Keys} keys - An object containing the encryption keys.
     * @returns {BitBuffer[]} - An array of BitBuffer objects representing the encrypted string.
     */
    static Encryption(string: string, keys: Keys): BitBufferArray;
    /**
     * Decrypts the provided cipher BitBuffer array using the provided keys.
     *
     * @param {BitBuffer[]} cipherBitArray - An array of BitBuffer objects representing the cipher to decrypt.
     * @param {Keys} keys - An object containing the decryption keys.
     * @returns {string} - The decrypted string.
     */
    static Decryption(cipherBitArray: BitBufferArray, keys: Keys): string;
}
