import BitBuffer from './BitBuffer';
export default class Mapper {
    /** Utility class that provides methods for mapping bit buffers with given permutation or S-Box. */
    /**
     * Maps the given BitBuffer with the provided permutation array.
     *
     * @param {ReadonlyArray<number>} permutation - The permutation array.
     * @param {BitBuffer} buffer - The BitBuffer to be mapped.
     * @returns {BitBuffer} A new BitBuffer mapped using the provided permutation array.
     */
    static MapPermutation(permutation: ReadonlyArray<number>, buffer: BitBuffer): BitBuffer;
    /**
     * Maps the given BitBuffer with the provided S-Box array.
     *
     * @param {BitBuffer} buffer - The BitBuffer to be mapped.
     * @returns {BitBuffer} A new BitBuffer mapped using the provided S-Box array.
     */
    static MapWithSboxs(buffer: BitBuffer): BitBuffer;
    /**
     * Maps the given BitBuffer with the provided S-Box and mapping array.
     *
     * @private
     * @param {BitBuffer} buffer - The BitBuffer to be mapped.
     * @param {number[][]} sBox - The S-Box array.
     * @param {number[]} mapping - The mapping array.
     * @returns {number[]} An array of mapped values.
     */
    private static MapWithSbox;
}
