"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const BitBufferArray_1 = __importDefault(require("../class/BitBufferArray"));
const BitBuffer_1 = __importDefault(require("../class/BitBuffer"));
/**
 * Converts a string to a BitBufferArray, where each character of the string is represented as a BitBuffer.
 *
 * @returns {BitBufferArray} - A BitBufferArray object containing BitBuffer representations of each character in the
 *   string.
 */
String.prototype.toBinary = function () {
    const result = new BitBufferArray_1.default();
    for (let i = 0; i < this.length; i++) {
        const charCode = this.charCodeAt(i);
        const binary = charCode.toString(2);
        const string = binary.padStart(8, '0');
        const buffer = new BitBuffer_1.default(Array.from(string).map(Number));
        result.push(buffer);
    }
    return result;
};
/**
 * Pads the current string with another string until it reaches the specified length.
 *
 * @param {number} maxLength - The length to pad the string to.
 * @param {string} fillString - The string to use as padding. If this string is longer than one character, the first
 *   character will be used as the padding.
 * @returns {string} - A padded string.
 */
String.prototype.padStart = function (maxLength, fillString) {
    let str = this.toString();
    while (str.length < maxLength) {
        str = fillString + str;
    }
    return str;
};
